#!/bin/sh
#
# check_vas - Nagios plugin, checks VAS file age, processes, NIS maps
# by Michael Tosch

# parameters: CRITnismaps CRITgroups CRITusers
# defaults:   10          10         10

nismaps=${1:-10}
nisgroups=${2:-10}
nisusers=${3:-$nisgroups}

set -f
PATH=/usr/bin:/bin:/usr/sbin:/sbin
export PATH

case $1 in
-*) echo "Usage: $0 [WARN nismaps] [WARN nisgroups] [WARN nisusers]"; exit 3;;
esac

# file age
file=vas_ident.vdb
if cd /var/opt/quest/vas/vasd 2>/dev/null && [ -f $file ]
then
  msg=`ls -lo $file | awk '{print "size="$4,$5,$6,$7,$8}'`
  if [ -z "`find $file -mtime -1`" ]
  then
    echo "File age CRITICAL: $msg"
    exit 2
  fi
else
  echo "Not found: $file"
  exit 3
fi

# processes
# ps zone|scope option
zone=`{ /sbin/zonename; } 2>/dev/null`
zopt=${zone:+"-o zone="}

# total VAS processes (vasd+vasgp + vasypd)
# https://support.software.dell.com/authentication-services/kb/49496
# VAS3: (3..4) + 2, QAS4: 5 + 2, QAS4.1: (6..9) + 2
UNIX95=1 ps -u root,daemon -o comm= -o etime= $zopt | awk '
($3!=zone || $2!~/[1-9]/) {next}
($1~/(^|\/)\.vasd$/) {q++; next}
($1~/(^|\/)vas(gp)?d$/) {v++; next}
($1~/(^|\/)\.?vasypd$/) {yp++}
END {
if (v==0 && (q<5 || q>9) || q==0 && (v<3 || v>5) || v>0 && q>0 || yp!=2) {
  print "Proc count CRITICAL:","vasd="q+v,"vasypd="yp+0; exit 2}
}' zone="$zone"
[ $? -eq 2 ] && exit 2

# NIS maps
mapcnt=`ypwhich -m 2>/dev/null | grep -c .`
if [ $mapcnt -lt $nismaps ]
then
  if [ $mapcnt -lt 5 ]; then
    echo "Map count CRITICAL: $mapcnt"
    exit 2
  else
    echo "Map count WARNING: $mapcnt"
    exit 1
  fi
fi
groupcnt=`ypcat group 2>/dev/null | grep -c .`
if [ $groupcnt -lt $nisgroups ]
then
  if [ $groupcnt -lt 2 ]; then
    echo "Group count CRITICAL: $groupcnt"
    exit 2
  else
    echo "Group count WARNING: $groupcnt"
    exit 1
  fi
fi
if [ $nismaps -ge 5 ] &&
  grep -lw client-addrs /etc/opt/quest/vas/vas.conf >/dev/null 2>&1
then
  netgrcnt=`ypcat netgroup 2>/dev/null | grep -c .`
  if [ $netgrcnt -eq 0 ]; then
    echo "netgroup count CRITICAL: $netgrcnt"
    exit 2
  fi
  usercnt=`ypcat passwd 2>/dev/null | grep -c .`
  if [ $usercnt -lt $nisusers ]
  then
    if [ $usercnt -lt 4 ]; then
      echo "User count CRITICAL: $usercnt"
      exit 2
    else
      echo "User count WARNING: $usercnt"
      exit 1
    fi
  fi
  msg="users=$usercnt netgroups=$netgrcnt $msg"
fi
echo "${usercnt:+Proxy }OK: maps=$mapcnt groups=$groupcnt $msg"
